# Import the libraries to use time delays, send os commands and access GPIO pins
import RPi.GPIO as GPIO 
import time 
import os 
import mpd 

# Setup Variables
RedLedPin = 13 # Set pin number for "Standby" LED
GreenLedPin = 15 # Set pin number for "ON" LED
MainRelayPin = 11 # Set pin number for relay output
counter = 0 # counter for determining the time that has passed since MoOde player has stopped
SleepTime = 60 # The delay between each Status check, set to 60 = 1 minute to save CPU 
StandbyTime = 4 # The amount of time before "Standby" defined in multiples of SleepTime: StandbyTime*SleepTime (60*4 = 240sec = 4 minutes)

# Setup GPIO pins
GPIO.setmode(GPIO.BOARD) # Set pin numbering to board numbering 
GPIO.setup(MainRelayPin, GPIO.OUT) # Setup pin MainRelayPin as an output 
GPIO.setup(RedLedPin, GPIO.OUT) # Setup pin RedLedPin as an output 
GPIO.setup(GreenLedPin, GPIO.OUT) # Setup pin GreenLedPin as an output 

# Setup MDPClient and connect to MPD on localhost
Client = mpd.MPDClient() # create client object 
while True:
	try:
		Client.connect("localhost", 6600) # connect to localhost:6600 
	except:
		continue
	break


# Set GPIO pins to their initial ON state
GPIO.output(MainRelayPin, GPIO.HIGH) 
GPIO.output(RedLedPin, GPIO.LOW) 
GPIO.output(GreenLedPin, GPIO.HIGH) 

# main loop
while True: # Setup a while loop to wait for a button press
	
	counter = counter + 1
	# print ("Checking MPD status! {0} seconds have passed since last MPD was last playing.".format((counter-1)*SleepTime))

	if Client.status()['state'] == "play":
		counter = 0
		# print ("MPD is Playing, Reseting counter to {0}".format(counter))

	if counter > StandbyTime:
		# print ("MPD has not been playing for {0} seconds! Entering standby!".format((counter-1)*SleepTime))
		
		# Set GPIO pins to standby state
		GPIO.output(MainRelayPin, GPIO.LOW)
		GPIO.output(GreenLedPin, GPIO.LOW)
		GPIO.output(RedLedPin, GPIO.HIGH)
		
		# wait for MPD to return Idle signaling that subsystem 'player' has changed
		# print "Waiting for Standby exit signal......."
		while Client.status()['state']=='stop':
			Id = Client.idle('player')
		# print "Standby exit signal received. Entering ON state"
		
		# Set GPIO pins to initial ON state
		GPIO.output(MainRelayPin, GPIO.HIGH)
		GPIO.output(RedLedPin, GPIO.LOW)
		GPIO.output(GreenLedPin, GPIO.HIGH)
		counter = 0

	time.sleep(SleepTime) # Allow a sleep time of SleepTime seconds to reduce CPU usage

# Close connection to MPD (not used since the main loop never exits)
Client.close() # send the close command
Client.disconnect() # disconnect from the server
